@@ -69,10 +69,13 @@ class HangmanTestCase(unittest.TestCase):
         self.assertIn('game', clean_variables.keys(), 'You should have a variable named game in your function play_game')
         self.assertIn('Hangman', clean_variables.values(), 'You should have a variable named game in your function play_game, and it should be an instance of the Game class')
         # Checks that the Game class is accepting the word_list parameter and number of lives
+        parameters = []
         if isinstance(variables['game'], ast.Call):
-            parameters = variables['game'].args
+            args = variables['game'].args
+            keywords = variables['game'].keywords
+            parameters = args + keywords
         
-        self.assertEqual(len(parameters), 2, 'You should pass two arguments to your Game class: word_list and number_of_lives')
+        self.assertEqual(len(parameters), 2, 'You should pass two arguments to your Game class: word_list and num_lives')
         self.assertEqual(len(whiles), 1, 'You should have a while loop in your play_game function')
         ifs_in_while = read_while(node)
         self.assertGreaterEqual(len(ifs_in_while), 1, 'You should have at least one if statement in your while loop to check if the game is over')
